__title__ = 'pyroboard'
__version__ = '0.1.1'
__author__ = 'PyMaster'
__license__ = 'MIT License'
__copyright__ = 'Copyright 2020 PyMaster'

from .inline_keyboard import InlineKeyboard
from .inline_pagination_keyboard import InlinePaginationKeyboard
from .reply_keyboard import ReplyKeyboard
